Examples
===========

It is very easy to use the SCRIP, which you only need to write a single command line as mentioned in "Usage" part. Here, we provide 4 examples that applied SCRIP to diverse biological systems and used the results to analyze more interesting biological findings. We provided custom some analyzing codes here, and detailed methods and conclusions can be found in our paper and `Github <https://github.com/xindong95/SCRIP_notebook>`_.

.. nbgallery::

   examples/PBMC
   examples/HSC
   examples/fetal_organ
   examples/Tumor_microenvironment

.. toctree::
   :hidden:

   examples/PBMC.rst
   examples/HSC.rst
   examples/fetal_organ.rst
   examples/Tumor_microenvironment.rst
